==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/it-IT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confermi elementi di eliminazione di massa',
    'bulk_restore'      => 'Conferma ripristino beni massivo', 
  'bulk_delete_help'	=> 'Rivedi gli assets sottostanti per la cancellazione massiva. Una volta cancellati, questi assets potranno essere ripristinati, ma non saranno più associati ad alcun utente cui siano attualmente assegnati.',
  'bulk_restore_help'	=> 'Esamina i beni da ripristinare qui sotto. Una volta recuperati, i beni non verranno riassegnati agli utenti a cui erano precedentemente assegnati.',
  'bulk_delete_warn'	=> 'Stai per cancellare :asset_count assets.',
  'bulk_restore_warn'	=> 'Stai per ripristinare :asset_count beni.',
    'bulk_update'		=> 'Aggiornamento quantità beni',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più risorse in una sola volta. Riempire solo i campi che è necessario cambiare. Tutti i campi lasciati vuoti rimarranno invariati. ',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di un singolo asset.<unk> Stai per modificare le proprietà di :asset_count asset.',
    'bulk_update_with_custom_field' => 'Nota che i beni sono di :asset_model_count modelli differenti.',
    'bulk_update_model_prefix' => 'Sui Modelli', 
    'bulk_update_custom_field_unique' => 'Questo è un campo unico e non può essere modificato massivamente.',
    'checkedout_to'		=> 'Assegnato a',
    'checkout_date'		=> 'Data del check-out',
    'checkin_date'		=> 'Data di entrata',
    'checkout_to'		=> 'Assegnare a',
    'cost'				=> 'Costo acquisto',
    'create'			=> 'Creare bene',
    'date'				=> 'Data di acquisto',
    'depreciation'	    => 'Ammortamento',
    'depreciates_on'	=> 'Deprezza Si',
    'default_location'	=> 'Posizione predefinita',
    'default_location_phone' => 'Telefono Posizione Predefinita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Tasso EOL',
    'expected_checkin'  => 'Richiesta Data di entrata',
    'expires'			=> 'Scade',
    'fully_depreciated'	=> 'Completamente ammortizzato',
    'help_checkout'		=> 'Se vuoi assegnare questo prodotto immediatamente, seleziona "Pronto alla spedizione" dalla barra di stato qui sopra. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Produttore',
    'model'				=> 'Modello',
    'months'			=> 'mesi',
    'name'				=> 'Nome bene',
    'notes'				=> 'Note',
    'order'				=> 'Numero Ordine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Gli utenti possono richiedere questo bene',
    'select_statustype'	=> 'Selezionare il tipo di stato',
    'serial'			=> 'Seriale',
    'status'			=> 'Stato',
    'tag'				=> 'Etichetta bene',
    'update'			=> 'Aggiornamento bene',
    'warranty'			=> 'Garanzia',
        'warranty_expires'		=> 'Scadenza della garanzia',
    'years'				=> 'anni',
    'asset_location' => 'Aggiorna Posizione Bene',
    'asset_location_update_default_current' => 'Aggiorna sia la posizione predefinita che quella attuale',
    'asset_location_update_default' => 'Aggiorna solo la posizione predefinita',
    'asset_location_update_actual' => 'Aggiorna solo la posizione effettiva',
    'asset_not_deployable' => 'Lo stato del bene è "Non Assegnabile". Non puoi fare il check-out di questo bene.',
    'asset_deployable' => 'Lo stato del bene è "Assegnabile". Puoi fare il check-out di questo bene.',
    'processing_spinner' => 'Elaborazione... (Può volerci un po\' su file di grandi dimensioni)',
    'optional_infos'  => 'Informazioni Opzionali',
    'order_details'   => 'Informazioni relative all\'ordine'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/it-IT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confermi elementi di eliminazione di massa',
    'bulk_restore'      => 'Conferma ripristino beni massivo', 
  'bulk_delete_help'	=> 'Rivedi gli assets sottostanti per la cancellazione massiva. Una volta cancellati, questi assets potranno essere ripristinati, ma non saranno più associati ad alcun utente cui siano attualmente assegnati.',
  'bulk_restore_help'	=> 'Esamina i beni da ripristinare qui sotto. Una volta recuperati, i beni non verranno riassegnati agli utenti a cui erano precedentemente assegnati.',
  'bulk_delete_warn'	=> 'Stai per cancellare :asset_count assets.',
  'bulk_restore_warn'	=> 'Stai per ripristinare :asset_count beni.',
    'bulk_update'		=> 'Aggiornamento quantità beni',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più risorse in una sola volta. Riempire solo i campi che è necessario cambiare. Tutti i campi lasciati vuoti rimarranno invariati. ',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di un singolo asset.<unk> Stai per modificare le proprietà di :asset_count asset.',
    'bulk_update_with_custom_field' => 'Nota che i beni sono di :asset_model_count modelli differenti.',
    'bulk_update_model_prefix' => 'Sui Modelli', 
    'bulk_update_custom_field_unique' => 'Questo è un campo unico e non può essere modificato massivamente.',
    'checkedout_to'		=> 'Assegnato a',
    'checkout_date'		=> 'Data del check-out',
    'checkin_date'		=> 'Data di entrata',
    'checkout_to'		=> 'Assegnare a',
    'cost'				=> 'Costo acquisto',
    'create'			=> 'Creare bene',
    'date'				=> 'Data di acquisto',
    'depreciation'	    => 'Ammortamento',
    'depreciates_on'	=> 'Deprezza Si',
    'default_location'	=> 'Posizione predefinita',
    'default_location_phone' => 'Telefono Posizione Predefinita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Tasso EOL',
    'expected_checkin'  => 'Richiesta Data di entrata',
    'expires'			=> 'Scade',
    'fully_depreciated'	=> 'Completamente ammortizzato',
    'help_checkout'		=> 'Se vuoi assegnare questo prodotto immediatamente, seleziona "Pronto alla spedizione" dalla barra di stato qui sopra. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Produttore',
    'model'				=> 'Modello',
    'months'			=> 'mesi',
    'name'				=> 'Nome bene',
    'notes'				=> 'Note',
    'order'				=> 'Numero Ordine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Gli utenti possono richiedere questo bene',
    'redirect_to_all'   => 'Ritorna a tutti i :type',
    'redirect_to_type'   => 'Vai a :type',
    'redirect_to_checked_out_to'   => 'Vai agli assegnati',
    'select_statustype'	=> 'Selezionare il tipo di stato',
    'serial'			=> 'Seriale',
    'status'			=> 'Stato',
    'tag'				=> 'Etichetta bene',
    'update'			=> 'Aggiornamento bene',
    'warranty'			=> 'Garanzia',
        'warranty_expires'		=> 'Scadenza della garanzia',
    'years'				=> 'anni',
    'asset_location' => 'Aggiorna Posizione Bene',
    'asset_location_update_default_current' => 'Aggiorna sia la posizione predefinita che quella attuale',
    'asset_location_update_default' => 'Aggiorna solo la posizione predefinita',
    'asset_location_update_actual' => 'Aggiorna solo la posizione effettiva',
    'asset_not_deployable' => 'Lo stato del bene è "Non Assegnabile". Non puoi fare il check-out di questo bene.',
    'asset_deployable' => 'Lo stato del bene è "Assegnabile". Puoi fare il check-out di questo bene.',
    'processing_spinner' => 'Elaborazione... (Può volerci un po\' su file di grandi dimensioni)',
    'optional_infos'  => 'Informazioni Opzionali',
    'order_details'   => 'Informazioni relative all\'ordine'
];
